==> moodle_1.3.1.orig.tar.gz: moodle/lang/es/calendar.php <==
<?PHP // $Id: calendar.php,v 1.5 2004/05/23 14:21:37 barias Exp $ 
      // calendar.php - created with Moodle 1.3 Nearly Ready (2004052000)


$string['april'] = 'Abril';
$string['august'] = 'Agosto';
$string['calendar'] = 'Calendario';
$string['calendarheading'] = '$a Calendario';
$string['clickhide'] = 'clic para ocultar';
$string['clickshow'] = 'clic para mostrar';
$string['confirmeventdelete'] = 'Est seguro de que desea eliminar este evento?';
$string['courseevents'] = 'Eventos de curso';
$string['dayview'] = 'Vista de Da';
$string['daywithnoevents'] = 'No hay eventos este da.';
$string['december'] = 'Diciembre';
$string['default'] = 'Por defecto';
$string['deleteevent'] = 'Eliminar evento';
$string['detailedmonthview'] = 'Vista de Mes detallada';
$string['durationminutes'] = 'Duracin en minutos';
$string['durationnone'] = 'Sin duracin';
$string['durationuntil'] = 'Hasta';
$string['editevent'] = 'Editando evento';
$string['errorbeforecoursestart'] = 'No puede fijar un evento antes de la fecha de comienzo del curso';
$string['errorinvaliddate'] = 'Fecha no vlida';
$string['errorinvalidminutes'] = 'Especifique la duracin en minutos con un nmero entre 1 y 999.';
$string['errorinvalidrepeats'] = 'Especifique el nmero de eventos con un nmero entre 1 y 99.';
$string['errornodescription'] = 'Se requiere una descripcin';
$string['errornoeventname'] = 'Se requiere un nombre';
$string['eventdate'] = 'Fecha';
$string['eventdescription'] = 'Descripcin';
$string['eventduration'] = 'Duracin';
$string['eventendtime'] = 'Hora final';
$string['eventinstanttime'] = 'Hora';
$string['eventkind'] = 'Tipo de evento';
$string['eventname'] = 'Nombre';
$string['eventrepeat'] = 'Repeticiones';
$string['eventsfor'] = '$a eventos';
$string['eventstarttime'] = 'Hora de comienzo';
$string['eventtime'] = 'Hora';
$string['eventview'] = 'Detalles del evento';
$string['expired'] = 'Expirado';
$string['explain_lookahead'] = 'Esta preferencia establece el nmero mximo de das en el futuro en que un evento debe comenzar con el fin de mostrarse como un evento prximo. Los eventos que comienzan ms tarde no se mostrarn como prximos. Por favor, note que <strong>no se garantiza</strong> que se muestren todos los eventos que comienzan en ese rango de fechas; si son demasiados (ms que los fijados en la preferencia \"Nmero mximo de eventos prximos\") entonces los eventos ms distantes no se mostrarn.';
$string['explain_maxevents'] = 'Esta preferencia establece el nmero mximo de eventos prximos a mostrar. Si selecciona un nmero alto, es posible que se ocupe un amplio espacio de la pantalla.';
$string['explain_startwday'] = 'Esta preferencia configura la forma en que se muestran todos los calendarios mensuales. Utilcela para acomodarla a su conveniencia.';
$string['explain_timeformat'] = 'Esta preferencia controla cmo aparecen las horas en el calendario. Puede elegir entre los formatos de 12 y 24 horas. Si elige la opcin \"por defecto\", entonces el formato se seleccionar automticamente de acuerdo con el idioma que usted utilice en el sitio.';
$string['february'] = 'Febrero';
$string['fri'] = 'Vie';
$string['friday'] = 'Viernes';
$string['globalevents'] = 'Eventos globales';
$string['gotocalendar'] = 'Ir al calendario';
$string['groupevents'] = 'Eventos de grupo';
$string['hidden'] = 'ocultos';
$string['january'] = 'Enero';
$string['july'] = 'Julio';
$string['june'] = 'Junio';
$string['manyevents'] = '$a eventos';
$string['march'] = 'Marzo';
$string['may'] = 'Mayo';
$string['mon'] = 'Lun';
$string['monday'] = 'Lunes';
$string['monthlyview'] = 'Vista de Mes';
$string['newevent'] = 'Nuevo Evento';
$string['noupcomingevents'] = 'No hay eventos prximos';
$string['november'] = 'Noviembre';
$string['october'] = 'Octubre';
$string['oneevent'] = '1 evento';
$string['pref_lookahead'] = 'Plazo de comienzo de eventos prximos';
$string['pref_maxevents'] = 'N mximo de eventos prximos';
$string['pref_startwday'] = 'Primer da de la semana';
$string['pref_timeformat'] = 'Formato de hora';
$string['preferences'] = 'Preferencias';
$string['preferences_available'] = 'Sus preferencias personales';
$string['repeatnone'] = 'No repeticiones';
$string['repeatweeksl'] = 'Repetir semanalmente, creando juntos';
$string['repeatweeksr'] = 'eventos';
$string['sat'] = 'Sb';
$string['saturday'] = 'Sbado';
$string['september'] = 'Septiembre';
$string['shown'] = 'visibles';
$string['spanningevents'] = 'Eventos en marcha';
$string['sun'] = 'Dom';
$string['sunday'] = 'Domingo';
$string['thu'] = 'Jue';
$string['thursday'] = 'Jueves';
$string['timeformat_12'] = '12 horas (am/pm)';
$string['timeformat_24'] = '24 horas';
$string['today'] = 'Hoy';
$string['tomorrow'] = 'Maana';
$string['tt_deleteevent'] = 'Eliminar evento';
$string['tt_editevent'] = 'Editar evento';
$string['tt_hidecourse'] = 'Eventos del curso visibles (clic para ocultar)';
$string['tt_hideglobal'] = 'Eventos globales visibles (clic para ocultar)';
$string['tt_hidegroups'] = 'Eventos de grupo visibles (clic para ocultar)';
$string['tt_hideuser'] = 'Eventos de usuario visibles (clic para ocultar)';
$string['tt_showcourse'] = 'Eventos del curso ocultos (clic para mostrar)';
$string['tt_showglobal'] = 'Eventos globales ocultos (clic para mostrar)';
$string['tt_showgroups'] = 'Eventos de grupo ocultos (clic para mostrar)';
$string['tt_showuser'] = 'Eventos de usuario ocultos (clic para mostrar)';
$string['tue'] = 'Mar';
$string['tuesday'] = 'Martes';
$string['typecourse'] = 'Evento de Curso';
$string['typegroup'] = 'Evento de Grupo';
$string['typesite'] = 'Evento de Sitio';
$string['typeuser'] = 'Evento de Usuario';
$string['upcomingevents'] = 'Eventos prximos';
$string['userevents'] = 'Eventos de Usuario';
$string['wed'] = 'Mi';
$string['wednesday'] = 'Mircoles';
$string['yesterday'] = 'Ayer';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/es/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.4 development (2004060100)


$string['calendar'] = 'Calendario';
$string['calendarheading'] = '$a Calendario';
$string['clickhide'] = 'clic para ocultar';
$string['clickshow'] = 'clic para mostrar';
$string['confirmeventdelete'] = 'Est seguro de que desea eliminar este evento?';
$string['courseevents'] = 'Eventos de curso';
$string['dayview'] = 'Vista de Da';
$string['daywithnoevents'] = 'No hay eventos este da.';
$string['default'] = 'Por defecto';
$string['deleteevent'] = 'Eliminar evento';
$string['detailedmonthview'] = 'Vista de Mes detallada';
$string['durationminutes'] = 'Duracin en minutos';
$string['durationnone'] = 'Sin duracin';
$string['durationuntil'] = 'Hasta';
$string['editevent'] = 'Editando evento';
$string['errorbeforecoursestart'] = 'No puede fijar un evento antes de la fecha de comienzo del curso';
$string['errorinvaliddate'] = 'Fecha no vlida';
$string['errorinvalidminutes'] = 'Especifique la duracin en minutos con un nmero entre 1 y 999.';
$string['errorinvalidrepeats'] = 'Especifique el nmero de eventos con un nmero entre 1 y 99.';
$string['errornodescription'] = 'Se requiere una descripcin';
$string['errornoeventname'] = 'Se requiere un nombre';
$string['eventdate'] = 'Fecha';
$string['eventdescription'] = 'Descripcin';
$string['eventduration'] = 'Duracin';
$string['eventendtime'] = 'Hora final';
$string['eventinstanttime'] = 'Hora';
$string['eventkind'] = 'Tipo de evento';
$string['eventname'] = 'Nombre';
$string['eventrepeat'] = 'Repeticiones';
$string['eventsfor'] = '$a eventos';
$string['eventstarttime'] = 'Hora de comienzo';
$string['eventtime'] = 'Hora';
$string['eventview'] = 'Detalles del evento';
$string['expired'] = 'Expirado';
$string['explain_lookahead'] = 'Esta preferencia establece el nmero mximo de das en que un evento debe comenzar para mostrarse como un evento prximo. Los eventos que comienzan ms tarde de esa fecha no se mostrarn como prximos. Por favor, advierta que <strong>no se garantiza</strong> que se muestren todos los eventos que comienzan en ese rango de fechas; si son demasiados (ms que los fijados en la preferencia \"Nmero mximo de eventos prximos\") entonces los eventos ms distantes no se mostrarn.';
$string['explain_maxevents'] = 'Esta preferencia establece el nmero mximo de eventos prximos a mostrar. Si selecciona un nmero alto, es posible que se ocupe un amplio espacio de la pantalla.';
$string['explain_startwday'] = 'Esta preferencia configura la forma en que se muestran todos los calendarios mensuales. Utilcela para acomodarla a su conveniencia.';
$string['explain_timeformat'] = 'Esta preferencia controla cmo aparecen las horas en el calendario. Puede elegir entre los formatos de 12 y 24 horas. Si elige la opcin \"por defecto\", entonces el formato se seleccionar automticamente de acuerdo con el idioma que usted utilice en el sitio.';
$string['fri'] = 'Vie';
$string['friday'] = 'Viernes';
$string['globalevents'] = 'Eventos globales';
$string['gotocalendar'] = 'Ir al calendario';
$string['groupevents'] = 'Eventos de grupo';
$string['hidden'] = 'ocultos';
$string['manyevents'] = '$a eventos';
$string['mon'] = 'Lun';
$string['monday'] = 'Lunes';
$string['monthlyview'] = 'Vista de Mes';
$string['newevent'] = 'Nuevo evento';
$string['noupcomingevents'] = 'No hay eventos prximos';
$string['oneevent'] = '1 evento';
$string['pref_lookahead'] = 'Plazo de comienzo de eventos prximos';
$string['pref_maxevents'] = 'N mximo de eventos prximos';
$string['pref_startwday'] = 'Primer da de la semana';
$string['pref_timeformat'] = 'Formato de hora';
$string['preferences'] = 'Preferencias';
$string['preferences_available'] = 'Sus preferencias personales';
$string['repeatnone'] = 'No repeticiones';
$string['repeatweeksl'] = 'Repetir semanalmente, creando juntos';
$string['repeatweeksr'] = 'eventos';
$string['sat'] = 'Sb';
$string['saturday'] = 'Sbado';
$string['shown'] = 'visibles';
$string['spanningevents'] = 'Eventos en marcha';
$string['sun'] = 'Dom';
$string['sunday'] = 'Domingo';
$string['thu'] = 'Jue';
$string['thursday'] = 'Jueves';
$string['timeformat_12'] = '12 horas (am/pm)';
$string['timeformat_24'] = '24 horas';
$string['today'] = 'Hoy';
$string['tomorrow'] = 'Maana';
$string['tt_deleteevent'] = 'Eliminar evento';
$string['tt_editevent'] = 'Editar evento';
$string['tt_hidecourse'] = 'Eventos del curso visibles (clic para ocultar)';
$string['tt_hideglobal'] = 'Eventos globales visibles (clic para ocultar)';
$string['tt_hidegroups'] = 'Eventos de grupo visibles (clic para ocultar)';
$string['tt_hideuser'] = 'Eventos de usuario visibles (clic para ocultar)';
$string['tt_showcourse'] = 'Eventos del curso ocultos (clic para mostrar)';
$string['tt_showglobal'] = 'Eventos globales ocultos (clic para mostrar)';
$string['tt_showgroups'] = 'Eventos de grupo ocultos (clic para mostrar)';
$string['tt_showuser'] = 'Eventos de usuario ocultos (clic para mostrar)';
$string['tue'] = 'Mar';
$string['tuesday'] = 'Martes';
$string['typecourse'] = 'Evento de curso';
$string['typegroup'] = 'Evento de grupo';
$string['typesite'] = 'Evento de sitio';
$string['typeuser'] = 'Evento de usuario';
$string['upcomingevents'] = 'Eventos prximos';
$string['userevents'] = 'Eventos de usuario';
$string['wed'] = 'Mi';
$string['wednesday'] = 'Mircoles';
$string['yesterday'] = 'Ayer';

?>
